# OneArgoPy
A Python library for accessing and visualizing Argo data.

The recommended installation is via pip (pip install oneargopy).

The included Jupyter notebook (oneargopy_demo.ipynb) demonstrates the basic usage of this library.

Python >= 3.10 is required for this library.

## Authors

* Savannah Stephenson (sstephenson2@islander.tamucc.edu)
* Hartmut Frenzel (hfrenzel@uw.edu)

  
